@@ -49,7 +49,7 @@
 /* #undef WITH_FAAC */
 /* #undef WITH_SOXR */
 #define WITH_GFX_H264
-/* #undef WITH_OPENH264 */
+#define WITH_OPENH264
 /* #undef WITH_OPENH264_LOADING */
 #define WITH_VIDEO_FFMPEG
 /* #undef WITH_DSP_EXPERIMENTAL */
@@ -89,6 +89,7 @@
 #define CHANNEL_DRIVE
 #define CHANNEL_DRIVE_CLIENT
 /* #undef CHANNEL_DRIVE_SERVER */
+
 #define CHANNEL_ECHO
 #define CHANNEL_ECHO_CLIENT
 #define CHANNEL_ECHO_SERVER
@@ -134,6 +135,9 @@
 #define CHANNEL_RDPECAM
 /* #undef CHANNEL_RDPECAM_CLIENT */
 #define CHANNEL_RDPECAM_SERVER
+/* #undef CHANNEL_RDPEAR */
+/* #undef CHANNEL_RDPEAR_CLIENT */
+/* #undef CHANNEL_RDPEAR_SERVER */
 #define CHANNEL_RDPEI
 #define CHANNEL_RDPEI_CLIENT
 #define CHANNEL_RDPEI_SERVER
@@ -231,6 +235,14 @@
  *
  * \since version 3.17.2
  */
+#if !defined(WITHOUT_FREERDP_3x_DEPRECATED)
 /* #undef WITHOUT_FREERDP_3x_DEPRECATED */
+#endif
+
+/** Build FILE_DIRECTORY_INFORMATION::FileName with type WCHAR instead of char
+ *
+ * @since version 3.20.0
+ */
+/* #undef WITH_WCHAR_FILE_DIRECTORY_INFORMATION */
 
 #endif /* FREERDP_CONFIG_H */
